/*
 * DEBUG: section 54    Interprocess Communication
 *
 */

#ifndef SQUID_IPC_FORWARD_H
#define SQUID_IPC_FORWARD_H

namespace Ipc
{

class TypedMsgHdr;
class StrandCoord;
class HereIamMessage;
class StrandSearchResponse;
class Forwarder;
class Inquirer;
class Request;
class Response;

} // namespace Ipc

#endif /* SQUID_IPC_FORWARD_H */
